djqgrid - a Django wrapper for jqGrid — djqgrid 0.2 documentation

### Navigation

- index
- modules |
- next |
- djqgrid 0.2 documentation »

# djqgrid - a Django wrapper for jqGrid

djqgrid is a Django wrapper for jqGrid.

djqgrid lets you define grids in a Django-familiar way, while taking care of most of the mundane Python-JavaScript bridge for you.

- Installation
- Example
- Reference

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- djqgrid 0.2 documentation »